==> hibernate-search-engine-4.6.1.Final-redhat-1-sources.jar: org/hibernate/search/util/impl/Maps.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * Copyright (c) 2014, Red Hat, Inc. and/or its affiliates or third-party contributors as
 * indicated by the @author tags or express copyright attribution
 * statements applied by the authors.  All third-party contributions are
 * distributed under license by Red Hat, Inc.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */

package org.hibernate.search.util.impl;

import java.util.EnumSet;
import java.util.concurrent.ConcurrentMap;

import org.hibernate.search.util.impl.ConcurrentReferenceHashMap.Option;
import org.hibernate.search.util.impl.ConcurrentReferenceHashMap.ReferenceType;

/**
 * Helper class to create maps with commonly needed constructors.
 *
 * @author Sanne Grinovero
 */
public class Maps {

	private Maps() {
		//not to be constructed
	}

	/**
	 * Creates a ConcurrentMap using weak references to keys, so that garbage collection
	 * of the key allows to remove the value from the map.
	 * Comparison on the keys is based on identity reference.
	 *
	 * @param initialSize for tuning of the initial size of the Map
	 * @param concurrencyLevel the estimated number of concurrently
	 * updating threads. The implementation performs internal sizing
	 * to try to accommodate this many threads.
	 * @return a new concurrent map with the properties described above.
	 */
	public static <K,V> ConcurrentMap<K,V> createIdentityWeakKeyConcurrentMap(int initialSize, int concurrencyLevel) {
		return new ConcurrentReferenceHashMap(
				initialSize, 0.75f, concurrencyLevel,
				ReferenceType.WEAK, ReferenceType.STRONG,
				EnumSet.of( Option.IDENTITY_COMPARISONS ) );
	}

}

==> hibernate-search-engine-5.6.0.Final-redhat-1-sources.jar: org/hibernate/search/util/impl/Maps.java <==
/*
 * Hibernate Search, full-text search for your domain model
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later
 * See the lgpl.txt file in the root directory or <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */

package org.hibernate.search.util.impl;

import java.util.EnumSet;
import java.util.concurrent.ConcurrentMap;

import org.hibernate.search.util.impl.ConcurrentReferenceHashMap.Option;
import org.hibernate.search.util.impl.ConcurrentReferenceHashMap.ReferenceType;

/**
 * Helper class to create maps with commonly needed constructors.
 *
 * @author Sanne Grinovero
 */
public class Maps {

	private Maps() {
		//not to be constructed
	}

	/**
	 * Creates a ConcurrentMap using weak references to keys, so that garbage collection
	 * of the key allows to remove the value from the map.
	 * Comparison on the keys is based on identity reference.
	 *
	 * @param <K> the key type in the map
	 * @param <V> the value type in the map
	 * @param initialSize for tuning of the initial size of the Map
	 * @param concurrencyLevel the estimated number of concurrently
	 * updating threads. The implementation performs internal sizing
	 * to try to accommodate this many threads.
	 * @return a new concurrent map with the properties described above.
	 */
	public static <K,V> ConcurrentMap<K,V> createIdentityWeakKeyConcurrentMap(int initialSize, int concurrencyLevel) {
		return new ConcurrentReferenceHashMap<>(
				initialSize, 0.75f, concurrencyLevel,
				ReferenceType.WEAK, ReferenceType.STRONG,
				EnumSet.of( Option.IDENTITY_COMPARISONS ) );
	}

}
